==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodIOChaosSpecFluent<A extends PodIOChaosSpecFluent<A>> extends Fluent<A>{
  public A addToActions(Integer index,IOChaosAction item);
  public A setToActions(Integer index,IOChaosAction item);
  public A addToActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items);
  public A addAllToActions(Collection<IOChaosAction> items);
  public A removeFromActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items);
  public A removeAllFromActions(Collection<IOChaosAction> items);
  public A removeMatchingFromActions(Predicate<IOChaosActionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildActions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IOChaosAction> getActions();
  public List<IOChaosAction> buildActions();
  public IOChaosAction buildAction(Integer index);
  public IOChaosAction buildFirstAction();
  public IOChaosAction buildLastAction();
  public IOChaosAction buildMatchingAction(Predicate<IOChaosActionBuilder> predicate);
  public Boolean hasMatchingAction(Predicate<IOChaosActionBuilder> predicate);
  public A withActions(List<IOChaosAction> actions);
  public A withActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... actions);
  public Boolean hasActions();
  public PodIOChaosSpecFluent.ActionsNested<A> addNewAction();
  public PodIOChaosSpecFluent.ActionsNested<A> addNewActionLike(IOChaosAction item);
  public PodIOChaosSpecFluent.ActionsNested<A> setNewActionLike(Integer index,IOChaosAction item);
  public PodIOChaosSpecFluent.ActionsNested<A> editAction(Integer index);
  public PodIOChaosSpecFluent.ActionsNested<A> editFirstAction();
  public PodIOChaosSpecFluent.ActionsNested<A> editLastAction();
  public PodIOChaosSpecFluent.ActionsNested<A> editMatchingAction(Predicate<IOChaosActionBuilder> predicate);
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  public String getVolumeMountPath();
  public A withVolumeMountPath(String volumeMountPath);
  public Boolean hasVolumeMountPath();
  public interface ActionsNested<N> extends Nested<N>,IOChaosActionFluent<PodIOChaosSpecFluent.ActionsNested<N>>{
    public N and();
    public N endAction();
    
  }
  
}

==> chaosmesh-model-6.7.2-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodIOChaosSpecFluent.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public interface PodIOChaosSpecFluent<A extends PodIOChaosSpecFluent<A>> extends Fluent<A>{
  public A addToActions(int index,IOChaosAction item);
  public A setToActions(int index,IOChaosAction item);
  public A addToActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items);
  public A addAllToActions(Collection<IOChaosAction> items);
  public A removeFromActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... items);
  public A removeAllFromActions(Collection<IOChaosAction> items);
  public A removeMatchingFromActions(Predicate<IOChaosActionBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildActions instead.
   * @return The buildable object.
   */
  @Deprecated
  public List<IOChaosAction> getActions();
  public List<IOChaosAction> buildActions();
  public IOChaosAction buildAction(int index);
  public IOChaosAction buildFirstAction();
  public IOChaosAction buildLastAction();
  public IOChaosAction buildMatchingAction(Predicate<IOChaosActionBuilder> predicate);
  public Boolean hasMatchingAction(Predicate<IOChaosActionBuilder> predicate);
  public A withActions(List<IOChaosAction> actions);
  public A withActions(io.fabric8.chaosmesh.v1alpha1.IOChaosAction... actions);
  public Boolean hasActions();
  public PodIOChaosSpecFluent.ActionsNested<A> addNewAction();
  public PodIOChaosSpecFluent.ActionsNested<A> addNewActionLike(IOChaosAction item);
  public PodIOChaosSpecFluent.ActionsNested<A> setNewActionLike(int index,IOChaosAction item);
  public PodIOChaosSpecFluent.ActionsNested<A> editAction(int index);
  public PodIOChaosSpecFluent.ActionsNested<A> editFirstAction();
  public PodIOChaosSpecFluent.ActionsNested<A> editLastAction();
  public PodIOChaosSpecFluent.ActionsNested<A> editMatchingAction(Predicate<IOChaosActionBuilder> predicate);
  public String getContainer();
  public A withContainer(String container);
  public Boolean hasContainer();
  public String getVolumeMountPath();
  public A withVolumeMountPath(String volumeMountPath);
  public Boolean hasVolumeMountPath();
  public interface ActionsNested<N> extends Nested<N>,IOChaosActionFluent<PodIOChaosSpecFluent.ActionsNested<N>>{
    public N and();
    public N endAction();
    
  }
  
}
